/v1/qemu/binaries — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Qemu »

# /v1/qemu/binaries

Contents

- /v1/qemu/binaries
  - GET /v1/qemu/binaries
    - Response status codes
    - Sample session

## GET /v1/qemu/binaries

Get a list of available Qemu binaries

### Response status codes

- 200: Success
- 400: Invalid request
- 404: Instance doesn’t exist

### Sample session

    curl -i -X GET 'http://localhost:8000/qemu/binaries'

    GET /qemu/binaries HTTP/1.1

    HTTP/1.1 200
    CONNECTION: keep-alive
    CONTENT-LENGTH: 134
    CONTENT-TYPE: application/json
    DATE: Thu, 08 Jan 2015 16:09:15 GMT
    SERVER: Python/3.4 GNS3/1.3.dev1
    X-ROUTE: /v1/qemu/binaries

    [
        {
            "path": "/tmp/1",
            "version": "2.2.0"
        },
        {
            "path": "/tmp/2",
            "version": "2.1.0"
        }
    ]

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Qemu »